from api.bag import adres_uitgebreid

def add_one(number):
    return number + 1

if __name__ == "__main__":
    x = add_one(2)
    print(x)
    adres_uitgebreid()